Create Fallback R Markdown Template
create_fallback_rmd_template.RdWrites a minimal R Markdown template to a temporary file and returns its path. Used when the package-bundled template cannot be found.
create_fallback_rmd_template.RdWrites a minimal R Markdown template to a temporary file and returns its path. Used when the package-bundled template cannot be found.