Create Fallback Report Template
create_fallback_template.RdDispatches to the appropriate fallback template creator based on the requested report format.
Usage
create_fallback_template(format = c("rmarkdown", "quarto"))create_fallback_template.RdDispatches to the appropriate fallback template creator based on the requested report format.
create_fallback_template(format = c("rmarkdown", "quarto"))