Get Template Path for Report Format
get_template_path.RdResolves the path to the bundled report template for the given format
using system.file().
get_template_path.RdResolves the path to the bundled report template for the given format
using system.file().