Validate Quarto Parameters
validate_quarto_params.RdCoerces and sanitises the parameter list before passing it to a Quarto render call. Provides safe defaults for all required parameters and removes characters that would break YAML parsing.
validate_quarto_params.RdCoerces and sanitises the parameter list before passing it to a Quarto render call. Provides safe defaults for all required parameters and removes characters that would break YAML parsing.